@@ -1,6 +1,6 @@
 package Getopt::EX::Hashed;
 
-our $VERSION = '0.9922';
+our $VERSION = '1.00';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Getopt::EX::Hashed - Hash store object automation for Getopt::Long
 
 =head1 VERSION
 
-Version 0.9922
+Version 1.00
 
 =head1 SYNOPSIS
 
@@ -82,6 +82,12 @@ sub import {
     }
 }
 
+sub unimport {
+    my $caller = caller;
+    no strict 'refs';
+    delete ${"$caller\::"}{$_} for @EXPORT;
+}
+
 sub configure {
     my $class = shift;
     my $config = do {
@@ -102,12 +108,6 @@ sub configure {
     return $class;
 }
 
-sub unimport {
-    no strict 'refs';
-    my $caller = caller;
-    delete ${"$caller\::"}{$_} for @EXPORT;
-}
-
 sub reset {
     my $caller = caller;
     my $member = __Member__($caller);
@@ -331,7 +331,7 @@ __END__
 =head1 DESCRIPTION
 
 B<Getopt::EX::Hashed> is a module to automate a hash object to store
-command line option values for B<Getopt::Long> or compatible module
+command line option values for B<Getopt::Long> and compatible modules
 including B<Getopt::EX::Long>.
 
 Major objective of this module is integrating initialization and
@@ -345,7 +345,9 @@ is given.
 
 =head1 FUNCTION
 
-=head2 B<has>
+=over 7
+
+=item B<has>
 
 Declare option parameters in a form of:
 
@@ -359,6 +361,11 @@ If the name start with plus (C<+>), given parameter updates values.
 
     has '+left' => ( default => 1 );
 
+As for C<spec> parameter, label can be omitted if it is the first
+parameter.
+
+    has left => "=i", default => 1;
+
 Following parameters are available.
 
 =over 7
@@ -371,7 +378,7 @@ only if it is the first parameter.
 In I<string>, option spec and alias names are separated by white
 space, and can show up in any order.  Declaration
 
-    has start => ( spec => "=i s begin" );
+    has start => "=i s begin";
 
 will be compiled into string:
 
@@ -380,12 +387,12 @@ will be compiled into string:
 which conform to C<Getopt::Long> definition.  Of course, you can write
 as this:
 
-    has start => ( spec => "s|begin=i" );
+    has start => "s|begin=i";
 
 If the name and aliases contain underscore (C<_>), another alias name
 is defined with dash (C<->) in place of underscores.  So
 
-    has a_to_z => ( spec => "=s" );
+    has a_to_z => "=s";
 
 will be compiled into:
 
@@ -399,6 +406,8 @@ string as a value.  Otherwise, it is not considered as an option.
 Additional alias names can be specified by B<alias> parameter too.
 There is no difference with ones in C<spec> parameter.
 
+    has start => "=i", alias => "s begin";
+
 =item B<is> => C<ro> | C<rw>
 
 To produce accessor method, C<is> parameter is necessary.  Set the
@@ -424,7 +433,7 @@ times and alter the member data.
 Parameter C<action> takes code reference which is called to process
 the option.  When called, hash object is passed as C<$_>.
 
-    has [ qw(left right both) ] => spec => '=i';
+    has [ qw(left right both) ] => '=i';
     has "+both" => action => sub {
         $_->{left} = $_->{right} = $_[1];
     };
@@ -475,18 +484,26 @@ Set the minimum and maximum limit for the argument.
 
 Set the valid string parameter list.  Each item is a string or a regex
 reference.  The argument is valid when it is same as, or match to any
-item of the given list.  If the value is not a arrayref, it is taken
+item of the given list.  If the value is not an arrayref, it is taken
 as a single item list (regexpref usually).
 
 Following declarations are almost equivalent, except second one is
 case insensitive.
 
     has question => '=s',
-        any => [ 'life', 'universe', 'everything ];
+        any => [ 'life', 'universe', 'everything' ];
 
     has question => '=s',
         any => qr/^(life|universe|everything)$/i;
 
+If you are using optional argument, don't forget to include default
+value in the list.  Otherwise it causes validation error.
+
+    has question => ':s',
+        any => [ 'life', 'universe', 'everything', '' ];
+
+=back
+
 =back
 
 =head1 METHOD
